@@ -59,15 +59,19 @@ class PythonSettings(AppSettings):
 
     @property
     def site_packages_abs(self):
+        version = '.'.join(self.version.split('.')[:2])
         return (
-            self.root_abs / 'lib' /
-            f'python{self.version[:3]}' / 'site-packages'
+            self.root_abs / 'lib' / f'python{version}' / 'site-packages'
         )
 
     @property
     def root_path(self):
         return self.root_abs / 'bin'
 
+    @property
+    def port(self):
+        return self._data.get('port', 8000)
+
 
 SETTINGS = PythonSettings()
 
