@@ -53,7 +53,8 @@ class DeploySettings(ComponentSettings):
             'roy.deploy.components.iptables',
             'roy.deploy.components.nginx',
             'roy.deploy.components.postgres',
-            'roy.deploy.components.redis'
+            'roy.deploy.components.redis',
+            'roy.deploy.components.nfs'
         ],
         'default_providers': [
             'roy.deploy.providers.vagrant',
@@ -70,8 +71,13 @@ class DeploySettings(ComponentSettings):
 
     @property
     def settings_cache_file(self):
-        cache_dir = APP_SETTINGS.current_dir
-        return (cache_dir / f".roy_{self.env}.json")
+        cache_name = f".roy_{self.env}.json"
+        cache_app_dir = APP_SETTINGS.current_dir
+        cache_settings_dir = Path(inspect.getfile(self.__class__)).parent
+        cache = cache_app_dir / cache_name
+        if not cache.exists():
+            cache = cache_settings_dir / cache_name
+        return cache
 
     @property
     def services(self):
@@ -126,8 +132,11 @@ class DeployComponentSettings:
 
     def __init__(self, settings=None, host=None):
         """Initialize deploy component settings, overrides by host settings"""
-        host_settings = self.get_for_host(host)
         host = host or {}
+        host_settings = self.get_for_host(host)
+
+        if not self.NAME:
+            raise ValueError(f'Provide NAME for settings {self.__class__}')
 
         settings = update_dict_recur(settings or {}, host_settings)
 
